@@ -1,7 +1,7 @@
 ((nil . ((whitespace-action auto-cleanup)
 	 (whitespace-style face empty trailing lines-tail)
 	 (require-final-newline . t)
-	 (mode . whitespace)))
+	 (mode . global-whitespace)))
  (c++-mode . ((c-default-style . "gnu")
 	      (indent-tab-mode . t)
 	      (tab-width . 8)
